@@ -89,6 +89,9 @@ def copy_db(ctx, source, destination, skip_backup=False, cleanup=True):
     print(progress("You may want to clear the redis cache now!"))
     print(progress(f"\t- gitops mcommand {destination} clear_cache"))
 
+    print(progress(":: Running migrations"))
+    run(f"gitops migrate {destination}", echo=True)
+
 
 @task
 def download_backup(ctx, app, index=None, path=None, datestamp=False):
@@ -170,10 +173,17 @@ def proxy(
         )
     else:
         proxy_dsn = modified_dsn.geturl()
+    print(
+        progress(
+            "Proxy established to :"
+            f"postgres://{modified_dsn.user}@{modified_dsn.hostname}:{modified_dsn.port}/{modified_dsn.dbname}\n"
+        )
+    )
     print(progress(f"Connect to the db using: {proxy_dsn}\n"))
     cmd = f"""aws ssm start-session  \
         --target {bastion_instance_id}  \
         --document-name AWS-StartPortForwardingSessionToRemoteHost \
+        --region {aws_availability_zone} \
         --parameters='{{"host": ["{database_dsn.host}"], "portNumber":["{database_dsn.port}"],"localPortNumber":["{local_port}"]}}'
     """
     return proxy_dsn, run(cmd, hide=True, asynchronous=background)
